@@ -8,19 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_autoscaling._jsii
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_s3._jsii
-import aws_cdk.aws_s3_deployment._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@pepperize/cdk-autoscaling-gitlab-runner",
-    "0.0.142",
+    "0.0.143",
     __name__[0:-6],
-    "cdk-autoscaling-gitlab-runner@0.0.142.jsii.tgz",
+    "cdk-autoscaling-gitlab-runner@0.0.143.jsii.tgz",
 )
 
 __all__ = [
